# cep_range

A biblioteca `cep_range` fornece funções relacionadas à obtenção de coordenadas geográficas, cálculo de distância entre dois pontos, obtenção de CEP a partir de coordenadas, busca de CEPs dentro de um raio específico, outros.

**Funções:**

1. `validate_cep(cep)`: Função para validar um CEP que retornar um formato padrão "XXXXX-XXX".

2. `get_coordinates(cep)`: Função para obter as coordenadas geográficas (`latitude` e `longitude`) a partir de um CEP. Utiliza o Selenium para abrir o Google Maps, inserir o CEP na barra de pesquisa, aguardar o carregamento da página e extrair as coordenadas da URL. Retorna as coordenadas como uma tupla `(latitude, longitude)`. Se as coordenadas não forem encontradas, gera uma mensagem de erro.

3. `calculate_distance(cep_1, cep_2, unit)`: Função para calcular a distância entre dois pontos geográficos. Obtém as coordenadas dos CEPs fornecidos usando a função `get_coordinates()`, converte as coordenadas para radianos e calcula a distância. O resultado é retornado em quilômetros (`unit='KM'`) ou metros (`unit='M'`). Se as coordenadas não forem encontradas para algum dos CEPs gera uma exceção `CoordinatesNotFoundError`.

4. `get_cep(latitude, longitude)`: Função para obter o CEP correspondente a um par de coordenadas geográficas (`latitude` e `longitude`). Utiliza Nominatim do Geopy para reverter a geocodificação e obter o CEP. Retorna o CEP se encontrado. Caso contrário, lança uma exceção indicando que não foi possível converter as coordenadas em CEP. Infelizmente o Nominatim pode retorna dados imprecisos.

5. `ceps_range(raio_m, cep_c)`: Função para gerar uma lista de CEPs únicos dentro de um determinado raio (em metros) a partir de um CEP central.

**Bibliotecas Necessárias:**
- geopy.geocoders.Nominatim: Biblioteca que fornece uma interface para o serviço de geocodificação do Nominatim, usado para converter coordenadas em CEP.
- selenium.webdriver: Módulo utilizado para automatizar a interação com um navegador web, usado para capturar dados de (`latitude` e `longitude`) de forma precisa.
- selenium.webdriver.common.by: 'By' Utilizada para localizar elementos em uma página.
- selenium.webdriver.support.ui.WebDriverWait: Classe utilizada para aguardar condições específicas de elementos da página.
- selenium.webdriver.support.expected_conditions
- math
- re

**Instalação**

```shell
pip install cep_range
```

Exemplos:
```python
 import cep_range

 ceps_raio_500m = cep_range.ceps_range(500, '01153-000')
 # output = ['01155-020', '01154-020', '01234-001', '01150-000', '01151-000', '01156-001', '01155-010', '01152-000', '01155-040', '01232-010', '01155-030', '01154-030', '01155-060', '01156-030', '01233-060', '01154-000', '01150-001', '01231-010', '01155-000', '01235-000', '01154-010']

 distancia = cep_range.calculate_distance('01150-000', '01154-010', 'm')
 # output = 829.704

 coordenadas = cep_range.get_coordinates('01154-010')
 # output = (-23.5290645, -46.6634956)
```


